# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from smart_diagnostics_client.api_client import ApiClient


class AssetsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_asset(self, **kwargs):  # noqa: E501
        """Creates an asset  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_asset(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AssetCreateRequest body:
        :return: AssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_asset_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_asset_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_asset_with_http_info(self, **kwargs):  # noqa: E501
        """Creates an asset  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_asset_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AssetCreateRequest body:
        :return: AssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_asset" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_asset_classification_category(self, **kwargs):  # noqa: E501
        """Creates a category  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_asset_classification_category(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AssetCategoryCreateRequest body:
        :return: AssetCategoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_asset_classification_category_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_asset_classification_category_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_asset_classification_category_with_http_info(self, **kwargs):  # noqa: E501
        """Creates a category  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_asset_classification_category_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AssetCategoryCreateRequest body:
        :return: AssetCategoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_asset_classification_category" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/Classifications/Category', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetCategoryResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_asset_classification_type(self, **kwargs):  # noqa: E501
        """Creates an asset classification type  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_asset_classification_type(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AssetClassificationTypeCreateRequest body:
        :return: AssetCategoryTypeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_asset_classification_type_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_asset_classification_type_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_asset_classification_type_with_http_info(self, **kwargs):  # noqa: E501
        """Creates an asset classification type  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_asset_classification_type_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AssetClassificationTypeCreateRequest body:
        :return: AssetCategoryTypeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_asset_classification_type" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/Classification/Types', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetCategoryTypeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_asset(self, asset_id, **kwargs):  # noqa: E501
        """Deletes an asset  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_asset(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
            return data

    def delete_asset_with_http_info(self, asset_id, **kwargs):  # noqa: E501
        """Deletes an asset  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_asset_with_http_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_asset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in params or
                params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `delete_asset`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in params:
            path_params['assetId'] = params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/{assetId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_asset_classification_category(self, category_id, **kwargs):  # noqa: E501
        """Deletes a category  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_asset_classification_category(category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int category_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_asset_classification_category_with_http_info(category_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_asset_classification_category_with_http_info(category_id, **kwargs)  # noqa: E501
            return data

    def delete_asset_classification_category_with_http_info(self, category_id, **kwargs):  # noqa: E501
        """Deletes a category  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_asset_classification_category_with_http_info(category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int category_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['category_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_asset_classification_category" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'category_id' is set
        if ('category_id' not in params or
                params['category_id'] is None):
            raise ValueError("Missing the required parameter `category_id` when calling `delete_asset_classification_category`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'category_id' in params:
            path_params['categoryId'] = params['category_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/Classifications/Category/{categoryId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_asset(self, asset_id, **kwargs):  # noqa: E501
        """Gets an Asset  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: (required)
        :param bool include_analytics_models: Determines whether to include the Analytics Model with the asset
        :return: AssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
            return data

    def get_asset_with_http_info(self, asset_id, **kwargs):  # noqa: E501
        """Gets an Asset  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_with_http_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: (required)
        :param bool include_analytics_models: Determines whether to include the Analytics Model with the asset
        :return: AssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset_id', 'include_analytics_models']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_asset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in params or
                params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `get_asset`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in params:
            path_params['assetId'] = params['asset_id']  # noqa: E501

        query_params = []
        if 'include_analytics_models' in params:
            query_params.append(('includeAnalyticsModels', params['include_analytics_models']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/{assetId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_asset_category_parameters(self, category_id, **kwargs):  # noqa: E501
        """Gets a list of Asset Classification parameters based on a given Category.  Includes any inherited parameters from any parent Categories.  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_category_parameters(category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int category_id: The Category (required)
        :param bool remove_duplicates: When true, inherited parameters with the same code will be removed
        :return: list[AssetCategoryParameterResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_asset_category_parameters_with_http_info(category_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_asset_category_parameters_with_http_info(category_id, **kwargs)  # noqa: E501
            return data

    def get_asset_category_parameters_with_http_info(self, category_id, **kwargs):  # noqa: E501
        """Gets a list of Asset Classification parameters based on a given Category.  Includes any inherited parameters from any parent Categories.  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_category_parameters_with_http_info(category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int category_id: The Category (required)
        :param bool remove_duplicates: When true, inherited parameters with the same code will be removed
        :return: list[AssetCategoryParameterResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['category_id', 'remove_duplicates']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_asset_category_parameters" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'category_id' is set
        if ('category_id' not in params or
                params['category_id'] is None):
            raise ValueError("Missing the required parameter `category_id` when calling `get_asset_category_parameters`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'category_id' in params:
            path_params['categoryId'] = params['category_id']  # noqa: E501

        query_params = []
        if 'remove_duplicates' in params:
            query_params.append(('removeDuplicates', params['remove_duplicates']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/Classification/Categories/{categoryId}/Parameters', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AssetCategoryParameterResponse]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_asset_classification_assignment(self, asset_id, **kwargs):  # noqa: E501
        """Gets the classification assignment for an asset  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_classification_assignment(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: (required)
        :return: AssetClassificationAssignmentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_asset_classification_assignment_with_http_info(asset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_asset_classification_assignment_with_http_info(asset_id, **kwargs)  # noqa: E501
            return data

    def get_asset_classification_assignment_with_http_info(self, asset_id, **kwargs):  # noqa: E501
        """Gets the classification assignment for an asset  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_classification_assignment_with_http_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: (required)
        :return: AssetClassificationAssignmentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_asset_classification_assignment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in params or
                params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `get_asset_classification_assignment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in params:
            path_params['assetId'] = params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/{assetId}/Classifications/Assignment', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetClassificationAssignmentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_asset_classification_categories(self, **kwargs):  # noqa: E501
        """Gets asset type categories.  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_classification_categories(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Active` | Boolean | `eq, neq` | | `AssetCategoryParentCode` | String | `eq, neq, like, in` | | `AssetCategoryParentId` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `AssetCategoryParentName` | String | `eq, neq, like, in` | | `AssetCategoryParentShortName` | String | `eq, neq, like, in` | | `Code` | String | `eq, neq, like, in` | | `Id` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `Name` | String | `eq, neq, like, in` | | `TypeCode` | String | `eq, neq, like, in` | | `TypeId` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `TypeName` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Active` | Boolean | | `Code` | String | | `Name` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Code`, `Name`.
        :return: PagedResultsModelAssetCategoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_asset_classification_categories_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_asset_classification_categories_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_asset_classification_categories_with_http_info(self, **kwargs):  # noqa: E501
        """Gets asset type categories.  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_classification_categories_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Active` | Boolean | `eq, neq` | | `AssetCategoryParentCode` | String | `eq, neq, like, in` | | `AssetCategoryParentId` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `AssetCategoryParentName` | String | `eq, neq, like, in` | | `AssetCategoryParentShortName` | String | `eq, neq, like, in` | | `Code` | String | `eq, neq, like, in` | | `Id` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `Name` | String | `eq, neq, like, in` | | `TypeCode` | String | `eq, neq, like, in` | | `TypeId` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `TypeName` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Active` | Boolean | | `Code` | String | | `Name` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Code`, `Name`.
        :return: PagedResultsModelAssetCategoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_asset_classification_categories" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/Classification/Categories', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelAssetCategoryResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_asset_classification_category(self, category_id, **kwargs):  # noqa: E501
        """Gets a category by id  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_classification_category(category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int category_id: (required)
        :return: AssetCategoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_asset_classification_category_with_http_info(category_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_asset_classification_category_with_http_info(category_id, **kwargs)  # noqa: E501
            return data

    def get_asset_classification_category_with_http_info(self, category_id, **kwargs):  # noqa: E501
        """Gets a category by id  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_classification_category_with_http_info(category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int category_id: (required)
        :return: AssetCategoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['category_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_asset_classification_category" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'category_id' is set
        if ('category_id' not in params or
                params['category_id'] is None):
            raise ValueError("Missing the required parameter `category_id` when calling `get_asset_classification_category`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'category_id' in params:
            path_params['categoryId'] = params['category_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/Classifications/Category/{categoryId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetCategoryResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_asset_classification_type(self, type_id, **kwargs):  # noqa: E501
        """Gets a type by id  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_classification_type(type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int type_id: (required)
        :return: AssetCategoryTypeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_asset_classification_type_with_http_info(type_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_asset_classification_type_with_http_info(type_id, **kwargs)  # noqa: E501
            return data

    def get_asset_classification_type_with_http_info(self, type_id, **kwargs):  # noqa: E501
        """Gets a type by id  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_classification_type_with_http_info(type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int type_id: (required)
        :return: AssetCategoryTypeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['type_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_asset_classification_type" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'type_id' is set
        if ('type_id' not in params or
                params['type_id'] is None):
            raise ValueError("Missing the required parameter `type_id` when calling `get_asset_classification_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'type_id' in params:
            path_params['typeId'] = params['type_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/Classification/Types/{typeId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetCategoryTypeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_asset_classification_types(self, **kwargs):  # noqa: E501
        """Gets a paged list of Asset Classification types  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_classification_types(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Id` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `Name` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Code` | String | | `Id` | Int32 | | `Name` | String |
        :return: PagedResultsModelAssetCategoryTypeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_asset_classification_types_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_asset_classification_types_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_asset_classification_types_with_http_info(self, **kwargs):  # noqa: E501
        """Gets a paged list of Asset Classification types  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_classification_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Id` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `Name` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Code` | String | | `Id` | Int32 | | `Name` | String |
        :return: PagedResultsModelAssetCategoryTypeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'page', 'page_limit', 'order_by']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_asset_classification_types" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/Classification/Types', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelAssetCategoryTypeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_asset_markers(self, asset_id, **kwargs):  # noqa: E501
        """Gets all markers on an asset  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_markers(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: Id of asset (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `MarkerType` | MarkerType | `eq, neq, in` | | `Name` | String | `eq, neq, like, in` | | `Value` | Double | `eq, neq, in, lt, gt, leq, geq` |
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Name` | String | | `Order` | Int32 | | `Value` | Double |
        :return: list[MarkerResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_asset_markers_with_http_info(asset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_asset_markers_with_http_info(asset_id, **kwargs)  # noqa: E501
            return data

    def get_asset_markers_with_http_info(self, asset_id, **kwargs):  # noqa: E501
        """Gets all markers on an asset  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_markers_with_http_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: Id of asset (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `MarkerType` | MarkerType | `eq, neq, in` | | `Name` | String | `eq, neq, like, in` | | `Value` | Double | `eq, neq, in, lt, gt, leq, geq` |
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Name` | String | | `Order` | Int32 | | `Value` | Double |
        :return: list[MarkerResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset_id', 'filter', 'order_by']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_asset_markers" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in params or
                params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `get_asset_markers`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in params:
            path_params['assetId'] = params['asset_id']  # noqa: E501

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/{assetId}/markers', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[MarkerResponse]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_asset_status(self, asset_id, **kwargs):  # noqa: E501
        """Gets an asset's status  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_status(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: (required)
        :return: GroupStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_asset_status_with_http_info(asset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_asset_status_with_http_info(asset_id, **kwargs)  # noqa: E501
            return data

    def get_asset_status_with_http_info(self, asset_id, **kwargs):  # noqa: E501
        """Gets an asset's status  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_status_with_http_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: (required)
        :return: GroupStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_asset_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in params or
                params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `get_asset_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in params:
            path_params['assetId'] = params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/{assetId}/Status', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GroupStatusResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_asset_statuses(self, group_ids, **kwargs):  # noqa: E501
        """Gets Asset Statuses  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_statuses(group_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] group_ids: (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `AlarmCount` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `DamageScore` | Double? | `eq, neq, in, lt, gt, leq, geq` | | `Id` | Guid | `eq, neq, in` | | `IsPaused` | Boolean | `eq, neq` | | `IsSnoozed` | Boolean | `eq, neq` | | `ModelCount` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `Name` | String | `eq, neq, like, in` | | `WarningCount` | Int32 | `eq, neq, in, lt, gt, leq, geq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `AlarmCount` | Int32 | | `DamageScore` | Double? | | `Name` | String | | `WarningCount` | Int32 |
        :return: PagedResultsModelGroupStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_asset_statuses_with_http_info(group_ids, **kwargs)  # noqa: E501
        else:
            (data) = self.get_asset_statuses_with_http_info(group_ids, **kwargs)  # noqa: E501
            return data

    def get_asset_statuses_with_http_info(self, group_ids, **kwargs):  # noqa: E501
        """Gets Asset Statuses  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_statuses_with_http_info(group_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] group_ids: (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `AlarmCount` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `DamageScore` | Double? | `eq, neq, in, lt, gt, leq, geq` | | `Id` | Guid | `eq, neq, in` | | `IsPaused` | Boolean | `eq, neq` | | `IsSnoozed` | Boolean | `eq, neq` | | `ModelCount` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `Name` | String | `eq, neq, like, in` | | `WarningCount` | Int32 | `eq, neq, in, lt, gt, leq, geq` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `AlarmCount` | Int32 | | `DamageScore` | Double? | | `Name` | String | | `WarningCount` | Int32 |
        :return: PagedResultsModelGroupStatusResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_ids', 'filter', 'page', 'page_limit', 'order_by']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_asset_statuses" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_ids' is set
        if ('group_ids' not in params or
                params['group_ids'] is None):
            raise ValueError("Missing the required parameter `group_ids` when calling `get_asset_statuses`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'group_ids' in params:
            query_params.append(('groupIds', params['group_ids']))  # noqa: E501
            collection_formats['groupIds'] = 'multi'  # noqa: E501
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/Status', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelGroupStatusResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_asset_types(self, **kwargs):  # noqa: E501
        """Gets Asset Types  # noqa: E501

        Required Permissions: Location User.  This route is obsolete. Please use GET /api/v3.0/Assets/Classification/Types instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_types(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `CategoryCode` | String | `eq, neq, like, in` | | `CategoryId` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `CategoryName` | String | `eq, neq, like, in` | | `Code` | String | `eq, neq, like, in` | | `Name` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Code` | String | | `Name` | String |
        :return: PagedResultsModelAssetTypeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_asset_types_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_asset_types_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_asset_types_with_http_info(self, **kwargs):  # noqa: E501
        """Gets Asset Types  # noqa: E501

        Required Permissions: Location User.  This route is obsolete. Please use GET /api/v3.0/Assets/Classification/Types instead.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_asset_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `CategoryCode` | String | `eq, neq, like, in` | | `CategoryId` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `CategoryName` | String | `eq, neq, like, in` | | `Code` | String | `eq, neq, like, in` | | `Name` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Code` | String | | `Name` | String |
        :return: PagedResultsModelAssetTypeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'page', 'page_limit', 'order_by']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_asset_types" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/Types', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelAssetTypeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_assets(self, **kwargs):  # noqa: E501
        """Gets Assets  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_assets(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] group_ids: The groupIds to grab assets from under
        :param bool include_analytics_models: Determines whether to include the Analytics Model with the asset
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Abbreviation` | String | `eq, neq, like, in` | | `Active` | Boolean | `eq, neq` | | `AnalyticsModelCount` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `AnalyticsModelId` | Guid | `eq, neq, in` | | `AnalyticsModelName` | String | `eq, neq, like, in` | | `CategoryCode` | String | `eq, neq, like, in` | | `CategoryId` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `CategoryName` | String | `eq, neq, like, in` | | `CategoryShortName` | String | `eq, neq, like, in` | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `Created` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `CriticalityId` | Int32? | `eq, neq, in, lt, gt, leq, geq` | | `CriticalityName` | String | `eq, neq, like, in` | | `HasWatchlistTicket` | Boolean | `eq, neq` | | `IsOperatorView` | Boolean | `eq, neq` | | `IsPaused` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `Manufacturer` | String | `eq, neq, like, in` | | `ModelName` | String | `eq, neq, like, in` | | `Name` | String | `eq, neq, like, in` | | `NodeId` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `NodeSerialNumber` | String | `eq, neq, like, in` | | `SizeCode` | String | `eq, neq, like, in` | | `SizeId` | Int32? | `eq, neq, in, lt, gt, leq, geq` | | `SizeName` | String | `eq, neq, like, in` | | `Supplier` | String | `eq, neq, like, in` | | `TagId` | Guid | `eq, neq, in` | | `TagName` | String | `eq, neq, like, in` | | `TypeCode` | String | `eq, neq, like, in` | | `TypeId` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `TypeName` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Abbreviation` | String | | `CategoryCode` | String | | `CategoryName` | String | | `CategoryShortName` | String | | `CorporationName` | String | | `Created` | DateTime | | `CriticalityId` | Int32? | | `CriticalityName` | String | | `LocationName` | String | | `Name` | String | | `SizeCode` | String | | `SizeName` | String | | `TypeCode` | String | | `TypeName` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Abbreviation`, `HierarchySearch`, `Name`.
        :return: PagedResultsModelAssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_assets_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_assets_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_assets_with_http_info(self, **kwargs):  # noqa: E501
        """Gets Assets  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_assets_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] group_ids: The groupIds to grab assets from under
        :param bool include_analytics_models: Determines whether to include the Analytics Model with the asset
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Abbreviation` | String | `eq, neq, like, in` | | `Active` | Boolean | `eq, neq` | | `AnalyticsModelCount` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `AnalyticsModelId` | Guid | `eq, neq, in` | | `AnalyticsModelName` | String | `eq, neq, like, in` | | `CategoryCode` | String | `eq, neq, like, in` | | `CategoryId` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `CategoryName` | String | `eq, neq, like, in` | | `CategoryShortName` | String | `eq, neq, like, in` | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `Created` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `CriticalityId` | Int32? | `eq, neq, in, lt, gt, leq, geq` | | `CriticalityName` | String | `eq, neq, like, in` | | `HasWatchlistTicket` | Boolean | `eq, neq` | | `IsOperatorView` | Boolean | `eq, neq` | | `IsPaused` | Boolean | `eq, neq` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `Manufacturer` | String | `eq, neq, like, in` | | `ModelName` | String | `eq, neq, like, in` | | `Name` | String | `eq, neq, like, in` | | `NodeId` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `NodeSerialNumber` | String | `eq, neq, like, in` | | `SizeCode` | String | `eq, neq, like, in` | | `SizeId` | Int32? | `eq, neq, in, lt, gt, leq, geq` | | `SizeName` | String | `eq, neq, like, in` | | `Supplier` | String | `eq, neq, like, in` | | `TagId` | Guid | `eq, neq, in` | | `TagName` | String | `eq, neq, like, in` | | `TypeCode` | String | `eq, neq, like, in` | | `TypeId` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `TypeName` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Abbreviation` | String | | `CategoryCode` | String | | `CategoryName` | String | | `CategoryShortName` | String | | `CorporationName` | String | | `Created` | DateTime | | `CriticalityId` | Int32? | | `CriticalityName` | String | | `LocationName` | String | | `Name` | String | | `SizeCode` | String | | `SizeName` | String | | `TypeCode` | String | | `TypeName` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Abbreviation`, `HierarchySearch`, `Name`.
        :return: PagedResultsModelAssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_ids', 'include_analytics_models', 'filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_assets" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'group_ids' in params:
            query_params.append(('groupIds', params['group_ids']))  # noqa: E501
            collection_formats['groupIds'] = 'multi'  # noqa: E501
        if 'include_analytics_models' in params:
            query_params.append(('includeAnalyticsModels', params['include_analytics_models']))  # noqa: E501
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelAssetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def move_asset(self, asset_id, **kwargs):  # noqa: E501
        """Moves an asset  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.move_asset(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: (required)
        :param GroupMoveRequest body:
        :return: AssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.move_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.move_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
            return data

    def move_asset_with_http_info(self, asset_id, **kwargs):  # noqa: E501
        """Moves an asset  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.move_asset_with_http_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: (required)
        :param GroupMoveRequest body:
        :return: AssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method move_asset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in params or
                params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `move_asset`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in params:
            path_params['assetId'] = params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/{assetId}/Move', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def replace_asset_markers(self, asset_id, **kwargs):  # noqa: E501
        """Replaces all the existing markers on the asset with new ones  # noqa: E501

        Required Permissions: User  Deprecated in favor of Create/Update/Delete /api/v3.0/Markers routes.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_asset_markers(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: Id of the asset (required)
        :param list[MarkerUpdateRequest] body: Request containing marker information
        :return: list[MarkerResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.replace_asset_markers_with_http_info(asset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.replace_asset_markers_with_http_info(asset_id, **kwargs)  # noqa: E501
            return data

    def replace_asset_markers_with_http_info(self, asset_id, **kwargs):  # noqa: E501
        """Replaces all the existing markers on the asset with new ones  # noqa: E501

        Required Permissions: User  Deprecated in favor of Create/Update/Delete /api/v3.0/Markers routes.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_asset_markers_with_http_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: Id of the asset (required)
        :param list[MarkerUpdateRequest] body: Request containing marker information
        :return: list[MarkerResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method replace_asset_markers" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in params or
                params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `replace_asset_markers`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in params:
            path_params['assetId'] = params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/{assetId}/markers', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[MarkerResponse]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_asset(self, asset_id, **kwargs):  # noqa: E501
        """Updates an asset  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_asset(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: (required)
        :param AssetUpdateRequest body:
        :return: AssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_asset_with_http_info(asset_id, **kwargs)  # noqa: E501
            return data

    def update_asset_with_http_info(self, asset_id, **kwargs):  # noqa: E501
        """Updates an asset  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_asset_with_http_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: (required)
        :param AssetUpdateRequest body:
        :return: AssetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_asset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in params or
                params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `update_asset`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in params:
            path_params['assetId'] = params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/{assetId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_asset_classification_category(self, category_id, **kwargs):  # noqa: E501
        """Updates a category  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_asset_classification_category(category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int category_id: (required)
        :param AssetCategoryUpdateRequest body:
        :return: AssetCategoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_asset_classification_category_with_http_info(category_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_asset_classification_category_with_http_info(category_id, **kwargs)  # noqa: E501
            return data

    def update_asset_classification_category_with_http_info(self, category_id, **kwargs):  # noqa: E501
        """Updates a category  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_asset_classification_category_with_http_info(category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int category_id: (required)
        :param AssetCategoryUpdateRequest body:
        :return: AssetCategoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['category_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_asset_classification_category" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'category_id' is set
        if ('category_id' not in params or
                params['category_id'] is None):
            raise ValueError("Missing the required parameter `category_id` when calling `update_asset_classification_category`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'category_id' in params:
            path_params['categoryId'] = params['category_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/Classifications/Category/{categoryId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetCategoryResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_asset_classification_parameters(self, category_id, **kwargs):  # noqa: E501
        """Updates the parameters for a given category  # noqa: E501

        Required Permissions: Saas only  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_asset_classification_parameters(category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int category_id: (required)
        :param AssetCategoryParameterUpdateRequest body:
        :return: list[AssetCategoryParameterResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_asset_classification_parameters_with_http_info(category_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_asset_classification_parameters_with_http_info(category_id, **kwargs)  # noqa: E501
            return data

    def update_asset_classification_parameters_with_http_info(self, category_id, **kwargs):  # noqa: E501
        """Updates the parameters for a given category  # noqa: E501

        Required Permissions: Saas only  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_asset_classification_parameters_with_http_info(category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int category_id: (required)
        :param AssetCategoryParameterUpdateRequest body:
        :return: list[AssetCategoryParameterResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['category_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_asset_classification_parameters" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'category_id' is set
        if ('category_id' not in params or
                params['category_id'] is None):
            raise ValueError("Missing the required parameter `category_id` when calling `update_asset_classification_parameters`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'category_id' in params:
            path_params['categoryId'] = params['category_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/Categories/{categoryId}/Parameters', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AssetCategoryParameterResponse]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_asset_classification_type(self, type_id, **kwargs):  # noqa: E501
        """Updates an asset classification type  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_asset_classification_type(type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int type_id: (required)
        :param AssetClassificationTypeUpdateRequest body:
        :return: AssetCategoryTypeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_asset_classification_type_with_http_info(type_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_asset_classification_type_with_http_info(type_id, **kwargs)  # noqa: E501
            return data

    def update_asset_classification_type_with_http_info(self, type_id, **kwargs):  # noqa: E501
        """Updates an asset classification type  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_asset_classification_type_with_http_info(type_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int type_id: (required)
        :param AssetClassificationTypeUpdateRequest body:
        :return: AssetCategoryTypeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['type_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_asset_classification_type" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'type_id' is set
        if ('type_id' not in params or
                params['type_id'] is None):
            raise ValueError("Missing the required parameter `type_id` when calling `update_asset_classification_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'type_id' in params:
            path_params['typeId'] = params['type_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/Classification/Types/{typeId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetCategoryTypeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_classification_assignment(self, asset_id, **kwargs):  # noqa: E501
        """Updates an assignment for classifications belonging to an asset.  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_classification_assignment(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: (required)
        :param AssetClassificationAssignmentUpdateRequest body:
        :return: AssetClassificationAssignmentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_classification_assignment_with_http_info(asset_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_classification_assignment_with_http_info(asset_id, **kwargs)  # noqa: E501
            return data

    def update_classification_assignment_with_http_info(self, asset_id, **kwargs):  # noqa: E501
        """Updates an assignment for classifications belonging to an asset.  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_classification_assignment_with_http_info(asset_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str asset_id: (required)
        :param AssetClassificationAssignmentUpdateRequest body:
        :return: AssetClassificationAssignmentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['asset_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_classification_assignment" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'asset_id' is set
        if ('asset_id' not in params or
                params['asset_id'] is None):
            raise ValueError("Missing the required parameter `asset_id` when calling `update_classification_assignment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'asset_id' in params:
            path_params['assetId'] = params['asset_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Assets/{assetId}/Classifications/Assignment', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AssetClassificationAssignmentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.users_api import UsersApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_corporation_permission(self):
        """Test case for add_corporation_permission

        """
        pass

    def test_add_location_permission(self):
        """Test case for add_location_permission

        Adds a location permission for the specified user  # noqa: E501
        """
        pass

    def test_check_email_exists(self):
        """Test case for check_email_exists

        Checks if the given email exists  # noqa: E501
        """
        pass

    def test_confirm_password_sd4(self):
        """Test case for confirm_password_sd4

        Confirms a user's new password when user resets their password.  # noqa: E501
        """
        pass

    def test_create_user(self):
        """Test case for create_user

        Create a new user  # noqa: E501
        """
        pass

    def test_delete_corporation_permission(self):
        """Test case for delete_corporation_permission

        Deletes a specific corporation permission  # noqa: E501
        """
        pass

    def test_delete_location_permission(self):
        """Test case for delete_location_permission

        Deletes a specific location permission  # noqa: E501
        """
        pass

    def test_delete_personal_access_token(self):
        """Test case for delete_personal_access_token

        Revokes one of the current user's access tokens.  # noqa: E501
        """
        pass

    def test_generate_personal_access_tokens(self):
        """Test case for generate_personal_access_tokens

        Generate a new access token for the current user.  # noqa: E501
        """
        pass

    def test_get_current_user(self):
        """Test case for get_current_user

        Gets the Current user  # noqa: E501
        """
        pass

    def test_get_personal_access_token(self):
        """Test case for get_personal_access_token

        Get one of the current user's access tokens.  # noqa: E501
        """
        pass

    def test_get_personal_access_tokens(self):
        """Test case for get_personal_access_tokens

        Lists the current user's access tokens.  # noqa: E501
        """
        pass

    def test_get_profile_options(self):
        """Test case for get_profile_options

        Gets all possible options for user profile properties  # noqa: E501
        """
        pass

    def test_get_user(self):
        """Test case for get_user

        Returns a specified user  # noqa: E501
        """
        pass

    def test_get_user_locations(self):
        """Test case for get_user_locations

        Returns a paged list of all locations that the selected user and accessing user both have access to  # noqa: E501
        """
        pass

    def test_get_user_profile(self):
        """Test case for get_user_profile

        Gets a user's profile  # noqa: E501
        """
        pass

    def test_get_users(self):
        """Test case for get_users

        Returns a paged list of all users  # noqa: E501
        """
        pass

    def test_reset_password_sd4(self):
        """Test case for reset_password_sd4

        Requests that a users password be reset. The users will receive an email with  instructions on how to reset their password.  # noqa: E501
        """
        pass

    def test_send_confirmation_code(self):
        """Test case for send_confirmation_code

        Sends a confirmation code to the supplied phone number  # noqa: E501
        """
        pass

    def test_unlock_user(self):
        """Test case for unlock_user

        Unlocks the user with the specified id (Sets LockedOut to false)  # noqa: E501
        """
        pass

    def test_update_corporation_permission(self):
        """Test case for update_corporation_permission

        Updates an existing user's corporation permission  # noqa: E501
        """
        pass

    def test_update_current_user(self):
        """Test case for update_current_user

        Updates the current user's information.  # noqa: E501
        """
        pass

    def test_update_location_permission(self):
        """Test case for update_location_permission

        Updates an existing user location permission  # noqa: E501
        """
        pass

    def test_update_personal_access_token(self):
        """Test case for update_personal_access_token

        Update one of the current user's access tokens.  # noqa: E501
        """
        pass

    def test_update_user(self):
        """Test case for update_user

        Updates a user  # noqa: E501
        """
        pass

    def test_update_user_profile(self):
        """Test case for update_user_profile

        Updates a user's profile  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class HubNodeChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'node_id': 'int',
        'node_serial_number': 'str',
        'node_nickname': 'str',
        'node_type_code': 'NodeTypeCodes',
        'is_online': 'bool',
        'node_settings': 'list[NodeSettingChild]',
        'latest_long_burst': 'LongBurstRequestChild'
    }

    attribute_map = {
        'node_id': 'NodeId',
        'node_serial_number': 'NodeSerialNumber',
        'node_nickname': 'NodeNickname',
        'node_type_code': 'NodeTypeCode',
        'is_online': 'IsOnline',
        'node_settings': 'NodeSettings',
        'latest_long_burst': 'LatestLongBurst'
    }

    def __init__(self, node_id=None, node_serial_number=None, node_nickname=None, node_type_code=None, is_online=None, node_settings=None, latest_long_burst=None):  # noqa: E501
        """HubNodeChild - a model defined in Swagger"""  # noqa: E501
        self._node_id = None
        self._node_serial_number = None
        self._node_nickname = None
        self._node_type_code = None
        self._is_online = None
        self._node_settings = None
        self._latest_long_burst = None
        self.discriminator = None
        self.node_id = node_id
        self.node_serial_number = node_serial_number
        if node_nickname is not None:
            self.node_nickname = node_nickname
        self.node_type_code = node_type_code
        if is_online is not None:
            self.is_online = is_online
        if node_settings is not None:
            self.node_settings = node_settings
        if latest_long_burst is not None:
            self.latest_long_burst = latest_long_burst

    @property
    def node_id(self):
        """Gets the node_id of this HubNodeChild.  # noqa: E501


        :return: The node_id of this HubNodeChild.  # noqa: E501
        :rtype: int
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this HubNodeChild.


        :param node_id: The node_id of this HubNodeChild.  # noqa: E501
        :type: int
        """
        if node_id is None:
            raise ValueError("Invalid value for `node_id`, must not be `None`")  # noqa: E501

        self._node_id = node_id

    @property
    def node_serial_number(self):
        """Gets the node_serial_number of this HubNodeChild.  # noqa: E501


        :return: The node_serial_number of this HubNodeChild.  # noqa: E501
        :rtype: str
        """
        return self._node_serial_number

    @node_serial_number.setter
    def node_serial_number(self, node_serial_number):
        """Sets the node_serial_number of this HubNodeChild.


        :param node_serial_number: The node_serial_number of this HubNodeChild.  # noqa: E501
        :type: str
        """
        if node_serial_number is None:
            raise ValueError("Invalid value for `node_serial_number`, must not be `None`")  # noqa: E501

        self._node_serial_number = node_serial_number

    @property
    def node_nickname(self):
        """Gets the node_nickname of this HubNodeChild.  # noqa: E501


        :return: The node_nickname of this HubNodeChild.  # noqa: E501
        :rtype: str
        """
        return self._node_nickname

    @node_nickname.setter
    def node_nickname(self, node_nickname):
        """Sets the node_nickname of this HubNodeChild.


        :param node_nickname: The node_nickname of this HubNodeChild.  # noqa: E501
        :type: str
        """

        self._node_nickname = node_nickname

    @property
    def node_type_code(self):
        """Gets the node_type_code of this HubNodeChild.  # noqa: E501


        :return: The node_type_code of this HubNodeChild.  # noqa: E501
        :rtype: NodeTypeCodes
        """
        return self._node_type_code

    @node_type_code.setter
    def node_type_code(self, node_type_code):
        """Sets the node_type_code of this HubNodeChild.


        :param node_type_code: The node_type_code of this HubNodeChild.  # noqa: E501
        :type: NodeTypeCodes
        """
        if node_type_code is None:
            raise ValueError("Invalid value for `node_type_code`, must not be `None`")  # noqa: E501

        self._node_type_code = node_type_code

    @property
    def is_online(self):
        """Gets the is_online of this HubNodeChild.  # noqa: E501


        :return: The is_online of this HubNodeChild.  # noqa: E501
        :rtype: bool
        """
        return self._is_online

    @is_online.setter
    def is_online(self, is_online):
        """Sets the is_online of this HubNodeChild.


        :param is_online: The is_online of this HubNodeChild.  # noqa: E501
        :type: bool
        """

        self._is_online = is_online

    @property
    def node_settings(self):
        """Gets the node_settings of this HubNodeChild.  # noqa: E501


        :return: The node_settings of this HubNodeChild.  # noqa: E501
        :rtype: list[NodeSettingChild]
        """
        return self._node_settings

    @node_settings.setter
    def node_settings(self, node_settings):
        """Sets the node_settings of this HubNodeChild.


        :param node_settings: The node_settings of this HubNodeChild.  # noqa: E501
        :type: list[NodeSettingChild]
        """

        self._node_settings = node_settings

    @property
    def latest_long_burst(self):
        """Gets the latest_long_burst of this HubNodeChild.  # noqa: E501


        :return: The latest_long_burst of this HubNodeChild.  # noqa: E501
        :rtype: LongBurstRequestChild
        """
        return self._latest_long_burst

    @latest_long_burst.setter
    def latest_long_burst(self, latest_long_burst):
        """Sets the latest_long_burst of this HubNodeChild.


        :param latest_long_burst: The latest_long_burst of this HubNodeChild.  # noqa: E501
        :type: LongBurstRequestChild
        """

        self._latest_long_burst = latest_long_burst

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HubNodeChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HubNodeChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GroupStatusResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'id': 'str',
        'alarm_count': 'int',
        'warning_count': 'int',
        'damage_score': 'float',
        'alarm_severity': 'int',
        'is_snoozed': 'bool',
        'is_paused': 'bool',
        'model_count': 'int',
        'ticket_count': 'int',
        'watchlist_ticket_id': 'str',
        'analytics_models': 'list[AnalyticsModelChild]',
        'hierarchy': 'list[HierarchyChild]'
    }

    attribute_map = {
        'name': 'Name',
        'id': 'Id',
        'alarm_count': 'AlarmCount',
        'warning_count': 'WarningCount',
        'damage_score': 'DamageScore',
        'alarm_severity': 'AlarmSeverity',
        'is_snoozed': 'IsSnoozed',
        'is_paused': 'IsPaused',
        'model_count': 'ModelCount',
        'ticket_count': 'TicketCount',
        'watchlist_ticket_id': 'WatchlistTicketId',
        'analytics_models': 'AnalyticsModels',
        'hierarchy': 'Hierarchy'
    }

    def __init__(self, name=None, id=None, alarm_count=None, warning_count=None, damage_score=None, alarm_severity=None, is_snoozed=None, is_paused=None, model_count=None, ticket_count=None, watchlist_ticket_id=None, analytics_models=None, hierarchy=None):  # noqa: E501
        """GroupStatusResponse - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._id = None
        self._alarm_count = None
        self._warning_count = None
        self._damage_score = None
        self._alarm_severity = None
        self._is_snoozed = None
        self._is_paused = None
        self._model_count = None
        self._ticket_count = None
        self._watchlist_ticket_id = None
        self._analytics_models = None
        self._hierarchy = None
        self.discriminator = None
        self.name = name
        self.id = id
        self.alarm_count = alarm_count
        self.warning_count = warning_count
        if damage_score is not None:
            self.damage_score = damage_score
        if alarm_severity is not None:
            self.alarm_severity = alarm_severity
        self.is_snoozed = is_snoozed
        self.is_paused = is_paused
        self.model_count = model_count
        self.ticket_count = ticket_count
        if watchlist_ticket_id is not None:
            self.watchlist_ticket_id = watchlist_ticket_id
        if analytics_models is not None:
            self.analytics_models = analytics_models
        if hierarchy is not None:
            self.hierarchy = hierarchy

    @property
    def name(self):
        """Gets the name of this GroupStatusResponse.  # noqa: E501


        :return: The name of this GroupStatusResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GroupStatusResponse.


        :param name: The name of this GroupStatusResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def id(self):
        """Gets the id of this GroupStatusResponse.  # noqa: E501


        :return: The id of this GroupStatusResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this GroupStatusResponse.


        :param id: The id of this GroupStatusResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def alarm_count(self):
        """Gets the alarm_count of this GroupStatusResponse.  # noqa: E501


        :return: The alarm_count of this GroupStatusResponse.  # noqa: E501
        :rtype: int
        """
        return self._alarm_count

    @alarm_count.setter
    def alarm_count(self, alarm_count):
        """Sets the alarm_count of this GroupStatusResponse.


        :param alarm_count: The alarm_count of this GroupStatusResponse.  # noqa: E501
        :type: int
        """
        if alarm_count is None:
            raise ValueError("Invalid value for `alarm_count`, must not be `None`")  # noqa: E501

        self._alarm_count = alarm_count

    @property
    def warning_count(self):
        """Gets the warning_count of this GroupStatusResponse.  # noqa: E501


        :return: The warning_count of this GroupStatusResponse.  # noqa: E501
        :rtype: int
        """
        return self._warning_count

    @warning_count.setter
    def warning_count(self, warning_count):
        """Sets the warning_count of this GroupStatusResponse.


        :param warning_count: The warning_count of this GroupStatusResponse.  # noqa: E501
        :type: int
        """
        if warning_count is None:
            raise ValueError("Invalid value for `warning_count`, must not be `None`")  # noqa: E501

        self._warning_count = warning_count

    @property
    def damage_score(self):
        """Gets the damage_score of this GroupStatusResponse.  # noqa: E501


        :return: The damage_score of this GroupStatusResponse.  # noqa: E501
        :rtype: float
        """
        return self._damage_score

    @damage_score.setter
    def damage_score(self, damage_score):
        """Sets the damage_score of this GroupStatusResponse.


        :param damage_score: The damage_score of this GroupStatusResponse.  # noqa: E501
        :type: float
        """

        self._damage_score = damage_score

    @property
    def alarm_severity(self):
        """Gets the alarm_severity of this GroupStatusResponse.  # noqa: E501


        :return: The alarm_severity of this GroupStatusResponse.  # noqa: E501
        :rtype: int
        """
        return self._alarm_severity

    @alarm_severity.setter
    def alarm_severity(self, alarm_severity):
        """Sets the alarm_severity of this GroupStatusResponse.


        :param alarm_severity: The alarm_severity of this GroupStatusResponse.  # noqa: E501
        :type: int
        """

        self._alarm_severity = alarm_severity

    @property
    def is_snoozed(self):
        """Gets the is_snoozed of this GroupStatusResponse.  # noqa: E501


        :return: The is_snoozed of this GroupStatusResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_snoozed

    @is_snoozed.setter
    def is_snoozed(self, is_snoozed):
        """Sets the is_snoozed of this GroupStatusResponse.


        :param is_snoozed: The is_snoozed of this GroupStatusResponse.  # noqa: E501
        :type: bool
        """
        if is_snoozed is None:
            raise ValueError("Invalid value for `is_snoozed`, must not be `None`")  # noqa: E501

        self._is_snoozed = is_snoozed

    @property
    def is_paused(self):
        """Gets the is_paused of this GroupStatusResponse.  # noqa: E501


        :return: The is_paused of this GroupStatusResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_paused

    @is_paused.setter
    def is_paused(self, is_paused):
        """Sets the is_paused of this GroupStatusResponse.


        :param is_paused: The is_paused of this GroupStatusResponse.  # noqa: E501
        :type: bool
        """
        if is_paused is None:
            raise ValueError("Invalid value for `is_paused`, must not be `None`")  # noqa: E501

        self._is_paused = is_paused

    @property
    def model_count(self):
        """Gets the model_count of this GroupStatusResponse.  # noqa: E501


        :return: The model_count of this GroupStatusResponse.  # noqa: E501
        :rtype: int
        """
        return self._model_count

    @model_count.setter
    def model_count(self, model_count):
        """Sets the model_count of this GroupStatusResponse.


        :param model_count: The model_count of this GroupStatusResponse.  # noqa: E501
        :type: int
        """
        if model_count is None:
            raise ValueError("Invalid value for `model_count`, must not be `None`")  # noqa: E501

        self._model_count = model_count

    @property
    def ticket_count(self):
        """Gets the ticket_count of this GroupStatusResponse.  # noqa: E501

        The number of tickets with which the Group is associated.  # noqa: E501

        :return: The ticket_count of this GroupStatusResponse.  # noqa: E501
        :rtype: int
        """
        return self._ticket_count

    @ticket_count.setter
    def ticket_count(self, ticket_count):
        """Sets the ticket_count of this GroupStatusResponse.

        The number of tickets with which the Group is associated.  # noqa: E501

        :param ticket_count: The ticket_count of this GroupStatusResponse.  # noqa: E501
        :type: int
        """
        if ticket_count is None:
            raise ValueError("Invalid value for `ticket_count`, must not be `None`")  # noqa: E501

        self._ticket_count = ticket_count

    @property
    def watchlist_ticket_id(self):
        """Gets the watchlist_ticket_id of this GroupStatusResponse.  # noqa: E501

        The id of the current watchlist ticket with which the Group is associated, if one exists.  # noqa: E501

        :return: The watchlist_ticket_id of this GroupStatusResponse.  # noqa: E501
        :rtype: str
        """
        return self._watchlist_ticket_id

    @watchlist_ticket_id.setter
    def watchlist_ticket_id(self, watchlist_ticket_id):
        """Sets the watchlist_ticket_id of this GroupStatusResponse.

        The id of the current watchlist ticket with which the Group is associated, if one exists.  # noqa: E501

        :param watchlist_ticket_id: The watchlist_ticket_id of this GroupStatusResponse.  # noqa: E501
        :type: str
        """

        self._watchlist_ticket_id = watchlist_ticket_id

    @property
    def analytics_models(self):
        """Gets the analytics_models of this GroupStatusResponse.  # noqa: E501


        :return: The analytics_models of this GroupStatusResponse.  # noqa: E501
        :rtype: list[AnalyticsModelChild]
        """
        return self._analytics_models

    @analytics_models.setter
    def analytics_models(self, analytics_models):
        """Sets the analytics_models of this GroupStatusResponse.


        :param analytics_models: The analytics_models of this GroupStatusResponse.  # noqa: E501
        :type: list[AnalyticsModelChild]
        """

        self._analytics_models = analytics_models

    @property
    def hierarchy(self):
        """Gets the hierarchy of this GroupStatusResponse.  # noqa: E501


        :return: The hierarchy of this GroupStatusResponse.  # noqa: E501
        :rtype: list[HierarchyChild]
        """
        return self._hierarchy

    @hierarchy.setter
    def hierarchy(self, hierarchy):
        """Sets the hierarchy of this GroupStatusResponse.


        :param hierarchy: The hierarchy of this GroupStatusResponse.  # noqa: E501
        :type: list[HierarchyChild]
        """

        self._hierarchy = hierarchy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GroupStatusResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GroupStatusResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ActivityEventCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'location_id': 'str',
        'category_id': 'int',
        'category_code': 'str',
        'created_by_user_name': 'str',
        'title': 'str',
        'description': 'str',
        'note': 'str',
        'start_date_time': 'datetime',
        'end_date_time': 'datetime',
        'document': 'ActivityEventDocumentRequest',
        'subcategories': 'list[ActivityEventSubcategoryEntryRequest]',
        'binds': 'list[ActivityEventBindRequest]',
        'fields': 'list[ActivityEventFieldEntryRequest]'
    }

    attribute_map = {
        'location_id': 'LocationId',
        'category_id': 'CategoryId',
        'category_code': 'CategoryCode',
        'created_by_user_name': 'CreatedByUserName',
        'title': 'Title',
        'description': 'Description',
        'note': 'Note',
        'start_date_time': 'StartDateTime',
        'end_date_time': 'EndDateTime',
        'document': 'Document',
        'subcategories': 'Subcategories',
        'binds': 'Binds',
        'fields': 'Fields'
    }

    def __init__(self, location_id=None, category_id=None, category_code=None, created_by_user_name=None, title=None, description=None, note=None, start_date_time=None, end_date_time=None, document=None, subcategories=None, binds=None, fields=None):  # noqa: E501
        """ActivityEventCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._location_id = None
        self._category_id = None
        self._category_code = None
        self._created_by_user_name = None
        self._title = None
        self._description = None
        self._note = None
        self._start_date_time = None
        self._end_date_time = None
        self._document = None
        self._subcategories = None
        self._binds = None
        self._fields = None
        self.discriminator = None
        self.location_id = location_id
        if category_id is not None:
            self.category_id = category_id
        if category_code is not None:
            self.category_code = category_code
        if created_by_user_name is not None:
            self.created_by_user_name = created_by_user_name
        self.title = title
        if description is not None:
            self.description = description
        if note is not None:
            self.note = note
        if start_date_time is not None:
            self.start_date_time = start_date_time
        if end_date_time is not None:
            self.end_date_time = end_date_time
        if document is not None:
            self.document = document
        if subcategories is not None:
            self.subcategories = subcategories
        if binds is not None:
            self.binds = binds
        if fields is not None:
            self.fields = fields

    @property
    def location_id(self):
        """Gets the location_id of this ActivityEventCreateRequest.  # noqa: E501

        Location of the activity event.  # noqa: E501

        :return: The location_id of this ActivityEventCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._location_id

    @location_id.setter
    def location_id(self, location_id):
        """Sets the location_id of this ActivityEventCreateRequest.

        Location of the activity event.  # noqa: E501

        :param location_id: The location_id of this ActivityEventCreateRequest.  # noqa: E501
        :type: str
        """
        if location_id is None:
            raise ValueError("Invalid value for `location_id`, must not be `None`")  # noqa: E501

        self._location_id = location_id

    @property
    def category_id(self):
        """Gets the category_id of this ActivityEventCreateRequest.  # noqa: E501

        Activity Event category id  <remarks>  Use either a CategoryId or CategoryCode, not both. One is required.  </remarks>  # noqa: E501

        :return: The category_id of this ActivityEventCreateRequest.  # noqa: E501
        :rtype: int
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """Sets the category_id of this ActivityEventCreateRequest.

        Activity Event category id  <remarks>  Use either a CategoryId or CategoryCode, not both. One is required.  </remarks>  # noqa: E501

        :param category_id: The category_id of this ActivityEventCreateRequest.  # noqa: E501
        :type: int
        """

        self._category_id = category_id

    @property
    def category_code(self):
        """Gets the category_code of this ActivityEventCreateRequest.  # noqa: E501

        Activity Event category code. Will be used to lookup the category instead of id.  Some examples of category codes:  <list type=\"bullet\">  ** <item><description>fault</description></item>  ** <item><description>correctivemaintenance</description></item>  ** <item><description>machineiq.fault</description></item></list><remarks>  Use either a CategoryId or CategoryCode, not both. One is required.  </remarks>  # noqa: E501

        :return: The category_code of this ActivityEventCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._category_code

    @category_code.setter
    def category_code(self, category_code):
        """Sets the category_code of this ActivityEventCreateRequest.

        Activity Event category code. Will be used to lookup the category instead of id.  Some examples of category codes:  <list type=\"bullet\">  ** <item><description>fault</description></item>  ** <item><description>correctivemaintenance</description></item>  ** <item><description>machineiq.fault</description></item></list><remarks>  Use either a CategoryId or CategoryCode, not both. One is required.  </remarks>  # noqa: E501

        :param category_code: The category_code of this ActivityEventCreateRequest.  # noqa: E501
        :type: str
        """

        self._category_code = category_code

    @property
    def created_by_user_name(self):
        """Gets the created_by_user_name of this ActivityEventCreateRequest.  # noqa: E501

        Username for created by field  # noqa: E501

        :return: The created_by_user_name of this ActivityEventCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._created_by_user_name

    @created_by_user_name.setter
    def created_by_user_name(self, created_by_user_name):
        """Sets the created_by_user_name of this ActivityEventCreateRequest.

        Username for created by field  # noqa: E501

        :param created_by_user_name: The created_by_user_name of this ActivityEventCreateRequest.  # noqa: E501
        :type: str
        """

        self._created_by_user_name = created_by_user_name

    @property
    def title(self):
        """Gets the title of this ActivityEventCreateRequest.  # noqa: E501

        Activity event title  # noqa: E501

        :return: The title of this ActivityEventCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this ActivityEventCreateRequest.

        Activity event title  # noqa: E501

        :param title: The title of this ActivityEventCreateRequest.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def description(self):
        """Gets the description of this ActivityEventCreateRequest.  # noqa: E501


        :return: The description of this ActivityEventCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ActivityEventCreateRequest.


        :param description: The description of this ActivityEventCreateRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def note(self):
        """Gets the note of this ActivityEventCreateRequest.  # noqa: E501


        :return: The note of this ActivityEventCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this ActivityEventCreateRequest.


        :param note: The note of this ActivityEventCreateRequest.  # noqa: E501
        :type: str
        """

        self._note = note

    @property
    def start_date_time(self):
        """Gets the start_date_time of this ActivityEventCreateRequest.  # noqa: E501


        :return: The start_date_time of this ActivityEventCreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date_time

    @start_date_time.setter
    def start_date_time(self, start_date_time):
        """Sets the start_date_time of this ActivityEventCreateRequest.


        :param start_date_time: The start_date_time of this ActivityEventCreateRequest.  # noqa: E501
        :type: datetime
        """

        self._start_date_time = start_date_time

    @property
    def end_date_time(self):
        """Gets the end_date_time of this ActivityEventCreateRequest.  # noqa: E501


        :return: The end_date_time of this ActivityEventCreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date_time

    @end_date_time.setter
    def end_date_time(self, end_date_time):
        """Sets the end_date_time of this ActivityEventCreateRequest.


        :param end_date_time: The end_date_time of this ActivityEventCreateRequest.  # noqa: E501
        :type: datetime
        """

        self._end_date_time = end_date_time

    @property
    def document(self):
        """Gets the document of this ActivityEventCreateRequest.  # noqa: E501


        :return: The document of this ActivityEventCreateRequest.  # noqa: E501
        :rtype: ActivityEventDocumentRequest
        """
        return self._document

    @document.setter
    def document(self, document):
        """Sets the document of this ActivityEventCreateRequest.


        :param document: The document of this ActivityEventCreateRequest.  # noqa: E501
        :type: ActivityEventDocumentRequest
        """

        self._document = document

    @property
    def subcategories(self):
        """Gets the subcategories of this ActivityEventCreateRequest.  # noqa: E501


        :return: The subcategories of this ActivityEventCreateRequest.  # noqa: E501
        :rtype: list[ActivityEventSubcategoryEntryRequest]
        """
        return self._subcategories

    @subcategories.setter
    def subcategories(self, subcategories):
        """Sets the subcategories of this ActivityEventCreateRequest.


        :param subcategories: The subcategories of this ActivityEventCreateRequest.  # noqa: E501
        :type: list[ActivityEventSubcategoryEntryRequest]
        """

        self._subcategories = subcategories

    @property
    def binds(self):
        """Gets the binds of this ActivityEventCreateRequest.  # noqa: E501


        :return: The binds of this ActivityEventCreateRequest.  # noqa: E501
        :rtype: list[ActivityEventBindRequest]
        """
        return self._binds

    @binds.setter
    def binds(self, binds):
        """Sets the binds of this ActivityEventCreateRequest.


        :param binds: The binds of this ActivityEventCreateRequest.  # noqa: E501
        :type: list[ActivityEventBindRequest]
        """

        self._binds = binds

    @property
    def fields(self):
        """Gets the fields of this ActivityEventCreateRequest.  # noqa: E501


        :return: The fields of this ActivityEventCreateRequest.  # noqa: E501
        :rtype: list[ActivityEventFieldEntryRequest]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this ActivityEventCreateRequest.


        :param fields: The fields of this ActivityEventCreateRequest.  # noqa: E501
        :type: list[ActivityEventFieldEntryRequest]
        """

        self._fields = fields

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivityEventCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityEventCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.documents_api import DocumentsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestDocumentsApi(unittest.TestCase):
    """DocumentsApi unit test stubs"""

    def setUp(self):
        self.api = DocumentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_generate_signed_user_manual_link(self):
        """Test case for generate_signed_user_manual_link

        Returns a temporary signed link to the User Manual from S3.  # noqa: E501
        """
        pass

    def test_get_manual_file(self):
        """Test case for get_manual_file

        Returns the User Manual as a pdf file.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
